SET client_min_messages = warning;

CREATE FUNCTION basis_in(cstring)
RETURNS basis AS '$libdir/eracer'
LANGUAGE C IMMUTABLE STRICT;

CREATE FUNCTION basis_out(basis)
RETURNS cstring AS '$libdir/eracer'
LANGUAGE C IMMUTABLE STRICT;

CREATE TYPE basis (
  INPUT = basis_in,
  OUTPUT = basis_out,
  STORAGE = extended
);

COMMENT ON FUNCTION basis_in(cstring) IS 'input function';
COMMENT ON FUNCTION basis_out(basis) IS 'output function';
COMMENT ON TYPE basis IS 'random variable data structure';

RESET client_min_messages;

CREATE FUNCTION new_basis(initval real)
RETURNS basis AS '$libdir/eracer'
LANGUAGE C IMMUTABLE;

CREATE FUNCTION new_basis(initval real, istddev real)
RETURNS basis AS '$libdir/eracer'
LANGUAGE C IMMUTABLE;

CREATE TYPE basis_info AS (
  size integer,
  initval real,
  istddev real,
  hasinit boolean,
  suspect boolean,
  round smallint,
  pdftype text,
  pdfmod smallint,
  pdflen smallint,
  expect real,
  stddev real,
  ci_min real,
  ci_max real
);

CREATE FUNCTION get_info(basis)
RETURNS basis_info AS '$libdir/eracer'
LANGUAGE C IMMUTABLE STRICT;

COMMENT ON FUNCTION new_basis(real) IS 'constructor for certain pdfs';
COMMENT ON FUNCTION new_basis(real, real) IS 'constructor for normal pdfs';
COMMENT ON TYPE basis_info IS 'relational view of basis internals';
COMMENT ON FUNCTION get_info(basis) IS 'constructs info for a basis';

--
-- PDF Support
--

CREATE FUNCTION expect(basis)
RETURNS real AS '$libdir/eracer'
LANGUAGE C IMMUTABLE STRICT;

CREATE FUNCTION stddev(basis)
RETURNS real AS '$libdir/eracer'
LANGUAGE C IMMUTABLE STRICT;

CREATE FUNCTION confint(basis, INOUT mass real,
OUT minv real, OUT maxv real) AS '$libdir/eracer'
LANGUAGE C IMMUTABLE STRICT;

CREATE FUNCTION diverge(basis, basis)
RETURNS real AS '$libdir/eracer'
LANGUAGE C IMMUTABLE STRICT;

COMMENT ON FUNCTION expect(basis) IS 'expected value';
COMMENT ON FUNCTION stddev(basis) IS 'standard deviation';
COMMENT ON FUNCTION confint(basis, real) IS 'confidence interval';
COMMENT ON FUNCTION diverge(basis, basis) IS 'JS divergence';
