DROP TABLE IF EXISTS person;
DROP TABLE IF EXISTS relative;
DROP TYPE IF EXISTS reltype;
DROP TABLE IF EXISTS stats;

CREATE TABLE person (
  ind_id integer NOT NULL,   -- identifies the individual
  birth smallint,            -- year of birth
  marry smallint,            -- year of first marriage
  death smallint,            -- year of death
  parent boolean NOT NULL,   -- is the individual a parent?
  female boolean NOT NULL,   -- is the individual a female?
  random real NOT NULL       -- random value for experiments
);

CREATE TYPE reltype AS ENUM (
  'I:self',
  'S:spouse',
  'P:parent',
  'C:child'
);

CREATE TABLE relative (
  ind_id integer NOT NULL,   -- identifies the individual
  rel_id integer NOT NULL,   -- identifies the relative
  role reltype NOT NULL      -- the type that rel_id is
);

CREATE TABLE stats (
  year integer NOT NULL,     -- simulation year
  immg integer NOT NULL,     -- number of immigrants
  death integer NOT NULL,    -- number of deaths
  sep integer NOT NULL,      -- number of separations
  mar integer NOT NULL,      -- number of marriages
  birth integer NOT NULL,    -- number of births
  pop integer NOT NULL,      -- population size
  fams integer NOT NULL      -- number of families
);

\copy person FROM 'out/person.csv' WITH CSV HEADER
CREATE INDEX person__ind_id ON person (ind_id);

\copy relative FROM 'out/relative.csv' WITH CSV HEADER
CREATE INDEX relative__ind_id ON relative (ind_id);
CREATE INDEX relative__rel_id ON relative (rel_id);

\copy stats FROM 'out/stats.csv' WITH CSV HEADER
CREATE INDEX stats__year ON stats (year);

ANALYZE VERBOSE person;
ANALYZE VERBOSE relative;
ANALYZE VERBOSE stats;
