"""
Basic cleaning of the Intel Lab Data: removes multiple reports within the same
time window, and throws out the obvious garbage tuples/values.
"""

from datetime import timedelta
from datetime import datetime
import sys

TS_START = "2004-02-28 00:58:15.0"
TS_FORMAT = "%Y-%m-%d %H:%M:%S.%f"
TD_WINDOW = timedelta(0, 16)


def get_ts(d, t):
    """Parses the date and time columns."""
    dt = d + ' ' + t
    try: # default format
        return datetime.strptime(dt, TS_FORMAT)
    except ValueError:
        pass
    try: # no microseconds
        return datetime.strptime(dt, TS_FORMAT[:-3])
    except ValueError:
        print d, t
        sys.exit(1)


def main():
    row_cnt = del_cnt = t_cnt = h_cnt = v_cnt = 0
    # track the previous report from each mote
    prev = datetime.strptime(TS_START, TS_FORMAT)
    pmap = dict([(m, prev) for m in range(1,55)])
    # open the input/output files
    dirty = open("src/data.txt", 'r')
    clean = open("out/clean.txt", 'w')
    for row in dirty:
        # get the next timestamp
        cols = row.split(' ')
        ts = get_ts(cols[0], cols[1])
        if ts < prev:
            print "ERROR: input file not sorted by timestamp"
            print "line ", 1 + row_cnt + del_cnt
            return
        # remove multiple reports per epoch
        if cols[3] == "":
            continue # 526 rows with NULL ids
        m = int(cols[3])
        if m not in pmap:
            continue # 9863 rows with invalid ids
        prev = pmap[m]
        if ts - prev < TD_WINDOW:
            del_cnt = del_cnt + 1
            continue
        pmap[m] = ts
        prev = ts
        # clear out garbage values
        if cols[4] != "":
            t = float(cols[4])
            if t < 15 or t > 35:
                cols[4] = ""
                t_cnt = t_cnt + 1
        if cols[5] != "":
            h = float(cols[5])
            if h < 15 or h > 60:
                cols[5] = ""
                h_cnt = h_cnt + 1
        if cols[7] != "":
            v = float(cols[7])
            if v < 2 or v > 3:
                cols[7] = "\n"
                v_cnt = v_cnt + 1
        # write the results
        clean.write(' '.join(cols))
        row_cnt = row_cnt + 1

    # display the results
    print "row_cnt = ", row_cnt
    print "del_cnt = ", del_cnt
    print "t_cnt = ", t_cnt
    print "h_cnt = ", h_cnt
    print "v_cnt = ", v_cnt


if __name__ == '__main__':
    main()
