#
# plots for emperical results
#

rm(list=ls(all=TRUE))

# data sets
status <- read.csv("status.csv")
res_aq <- read.csv("res_aq.csv")

# which attributes
dbname <- "sensor"
mround <- 5  # max(res_aq$r)
versions <- c(0,1,3,4,5,7)

if (dbname == "sensor") {
  rows <- 2269503
  legs <- c("Humidity", "Temperature")
  # x and y limits
  xlim.m <- c(25, 95)
  ylim.m <- c(0, 5)
  xlim.c <- c(5, 75)
  ylim.c <- c(0, 10)
  # column indexes from status
  c.mis <- c(2, 1)
  c.cor <- c.mis + 4
  # column indexes from res_aq
  c.mae <- c(5, 2)
  c.bas <- c.mae + 1
}

if (dbname == "popgen") {
  rows <- 1038466
  legs <- c("Death", "Birth")  
  # x and y limits
  xlim.m <- c(0, 100)
  ylim.m <- c(0, 60)
  xlim.c <- c(0, 100)
  ylim.c <- c(0, 180)
  # column indexes from status
  c.mis <- c(3, 1)
  c.cor <- c.mis + 3
  # column indexes from res_aq
  c.mae <- c(5, 2)
  c.bas <- c.mae + 1
}

#-------------------------------------------------------------------------------

# image/font sizes
img_w <- 3.0
img_h <- 2.1
fntsz <- 8

# axis labels 
xlbs <- c("Percent Missing", "Percent Corrupt")
ylbs <- c("Mean Absolute Error")

# colors/symbols for each curve
cols <- c("gray70", "gray35")
pchs <- c(17, 20)

# mean absolute error, given percent missing
plot.mae.m <- function() {
  xdat <- subset(status, status$v == vn & status$c == 0 & status$r == 0)
  mis <- xdat[,c.mis]
  cor <- xdat[,c.cor]
  ydat <- subset(res_aq, res_aq$v == vn & res_aq$c == 0 & res_aq$r == mround)
  mae <- ydat[,c.mae]
  bas <- ydat[,c.bas]
  # plot the current subset
  fn <- paste('mae_', vn, 'm.pdf', sep='')
  pdf(fn, width=img_w, height=img_h, family="Times", pointsize=fntsz)
  par(mai=c(0.7,0.7,0.1,0.1))
  plot(NULL, xlab=xlbs[1], ylab=ylbs[1], xlim=xlim.m, ylim=ylim.m)
  for (i in 1:length(mis)) {
    lines(100 * mis[,i] / rows, mae[,i], col=cols[i], pch=pchs[i], type="o")
    lines(100 * mis[,i] / rows, bas[,i], col=cols[i], pch=pchs[i], lty=2)
  }
  legend("topleft", legend=legs, col=cols, pch=pchs)
  dev.off()
}

# mean absolute error, given percent corrupt
plot.mae.c <- function() {
  xdat <- subset(status, status$v == vn & status$c > 0 & status$r == 0)
  mis <- xdat[,c.mis]
  cor <- xdat[,c.cor]
  ydat <- subset(res_aq, res_aq$v == vn & res_aq$c > 0 & res_aq$r == mround)
  mae <- ydat[,c.mae]
  bas <- ydat[,c.bas]
  # plot the current subset
  fn <- paste('mae_', vn, 'c.pdf', sep='')
  pdf(fn, width=img_w, height=img_h, family="Times", pointsize=fntsz)
  par(mai=c(0.7,0.7,0.1,0.1))
  plot(NULL, xlab=xlbs[2], ylab=ylbs[1], xlim=xlim.c, ylim=ylim.c)
  for (i in 1:length(cor)) {
    lines(100*cor[,i]/(rows-mis[,i]), mae[,i], col=cols[i], pch=pchs[i], type="o")
    lines(100*cor[,i]/(rows-mis[,i]), bas[,i], col=cols[i], pch=pchs[i], lty=2)
  }
  legend("topleft", legend=legs, col=cols, pch=pchs)
  dev.off()
}

# generate plots for each version
for (vn in versions) {
  plot.mae.m()
  plot.mae.c()
}
