--
-- example session using the intel lab data
-- (what to do after running install.sql)
--

SET search_path TO eracer, public;

--------------------------------------------------------------------------------
-- STEP 1: construct graphical model

ALTER TABLE node
  -- inferred values
  ADD COLUMN t basis NOT NULL,
  ADD COLUMN h basis NOT NULL,
  ADD COLUMN l basis NOT NULL,
  ADD COLUMN v basis NOT NULL;

-- 2,269,503 rows in 13,178 ms
INSERT INTO node
  SELECT
    make_nid(second, moteid),
    new_basis(temperature),
    new_basis(humidity),
    new_basis(light),
    new_basis(voltage)
  FROM clean;

-- improve performance of joining results
-- (i.e., sort*2 + mergejoin -> hashjoin)
CREATE UNIQUE INDEX clean__nid
ON clean (make_nid(second, moteid));

-- 8,079,884 rows in 53,184 ms
INSERT INTO link
  SELECT -- use 'a' to predict 'b'
    make_nid(b.second, b.moteid),
    make_nid(a.second, a.moteid),
    1 AS typ -- one type of link
  FROM clean AS a
    INNER JOIN near AS c ON a.moteid = c.id1
    INNER JOIN clean AS b ON c.id2 = b.moteid
  -- neighboring sensors at same epoch
  WHERE a.second - 30 <= b.second
    AND a.second + 30 >= b.second;

-- create indexes (see tables.sql)
-- node: 22,075 ms  link: 39,629 ms

--------------------------------------------------------------------------------
-- STEP 2: learn regression coefficients

ALTER TABLE model
  -- intra-tuple coefficients
  ADD COLUMN ti real NOT NULL,
  ADD COLUMN hi real NOT NULL,
  ADD COLUMN li real NOT NULL,
  ADD COLUMN vi real NOT NULL,
  -- neighbor coefficients
  ADD COLUMN tn real NOT NULL,
  ADD COLUMN hn real NOT NULL,
  ADD COLUMN ln real NOT NULL,
  ADD COLUMN vn real NOT NULL;

-- 100,000 rows in 31,677 ms (with subquery)
CREATE TABLE learn AS
  SELECT * FROM (
    SELECT
      -- individual instances
      min(expect(i.t))::real AS ti,
      min(expect(i.h))::real AS hi,
      min(expect(i.l))::real AS li,
      min(expect(i.v))::real AS vi,
      -- average neighbor values
      avg(expect(n.t))::real AS tn,
      avg(expect(n.h))::real AS hn,
      avg(expect(n.l))::real AS ln,
      avg(expect(n.v))::real AS vn
    FROM node AS i
      LEFT JOIN link AS l ON i.nid = l.dst
      LEFT JOIN node AS n ON l.src = n.nid
    GROUP BY i.nid
  ) AS sub
  ORDER BY random()
  LIMIT 100000;

ANALYZE VERBOSE learn;

--
-- do the one-time regression analysis offline; see learn/README.txt
-- (export learn table, run R and python scripts, import model table)
--

ANALYZE VERBOSE model;
SELECT model_sync();

--------------------------------------------------------------------------------
-- STEP 3: iterative approximate inference (see exper.py)
