#
# learn regression models over all subsets of attributes
# sample.csv + models.R -> models.txt + models.py -> models.csv
# 
# NOTE: the implementation is currently brute force; for a larger number of
# variables, this should use the regsubsets function from the leaps package
#

library(bitops)
require(quantreg)  # optional

d <- read.csv("models/sample.csv")
vars = names(d)
nvar = length(vars)

# optional argument: number of attributes to infer
atts <- as.integer(commandArgs(TRUE)[1])
if (is.na(atts)) {
  atts <- nvar/2  # assuming one type of neighbors
}

# model output function
lm.info <- function(formula) {
  m <- lm(formula, data=d)
  s <- summary(m)
  print(s)
  print(formula)
  print(paste("R-squared =", s$r.squared))
  print(paste("std error =", s$sigma))
  print(paste("d freedom =", s$df[2]))
  print(m$coefficients, digits=22)
}

# quantile regression models
tau <- c(.05, .25, .50, .75, .95)
rq.info <- function(formula) {
  print(formula)
  fm <- rq(formula, tau=tau, data=d, method="fn")
  print(paste("AIC value =", AIC(fm, k=2)))
  print(paste("resid dev =", sd(fm$residuals)))
  print(paste("resid len =", length(fm$residuals)))
  print(fm$coefficients, digits=22)
}

# for each response variable
for (i in seq(1, atts)) {
  # names are indexed from the least significant bit
  rv <- 2^(i-1)
  lhs <- vars[i]
  # for each possible bitwise combination
  for (bc in seq(1, 2^nvar-1)) {
    # skip subsets that include the response variable
    if (bitAnd(bc, rv) > 0) {
      next
    }
    # learn a regression model over this subset
    ss <- bitAnd(rep(bc, nvar), 2^seq(0, nvar-1)) > rep(0, nvar)
    rhs <- paste(subset(vars, ss), collapse=" + ")
    mod <- paste(lhs, rhs, sep=" ~ ")
    lm.info(mod)
  }
}

## Alternative approach; see http://www.statmethods.net/stats/regression.html
#library(leaps)
#rss <- regsubsets(bi~., data=d, nbest=4, nvmax=4, force.out=c(1,4,7,10))
#plot(rss, scale="r2")
#library(car)
#subsets(rss, statistic="rsq")
