"""
Generates a plots.tex file that includes all the .png's.
"""

import sys

# boilerplate LaTeX code

BEG = r"""
\documentclass{article}
\usepackage{graphicx}

\graphicspath{{intra/}{inter/}}

\newcommand{\img}[1]{\includegraphics[width=3.25in]{#1.png}}

% manually set the margins at 0.75in
\setlength{\oddsidemargin}{-0.5in}
\setlength{\evensidemargin}{1.0in}
\setlength{\textwidth}{7.5in}
\setlength{\topmargin}{-1.025in}
\setlength{\textheight}{10in}

\pagestyle{empty}

%-------------------------------------------------------------------------------
\begin{document}
Intra-tuple \hfill \today
"""

MID = r"""
%-------------------------------------------------------------------------------
\newpage
Inter-tuple \hfill \today
"""

END = r"""
%-------------------------------------------------------------------------------
\end{document}
"""


def write(fout, coli, colj, cnt):
    if cnt % 2 == 0:
        fout.write("\n")
    else:
        fout.write("\\hfill\n")
    fout.write(r"\img{" + coli + "_" + colj + "}\n")


def main():
    # get attribute names
    fin = open("models/sample.csv", 'r')
    line = fin.readline().rstrip()
    cols = line.split(',')
    ncol = len(cols)
    fin.close()
    # get the number of node attributes
    if len(sys.argv) > 1:
        atts = int(sys.argv[1])
    else:
        atts = ncol/2
    # generate the output
    fout = open("plots/plots.tex", 'w')
    fout.write(BEG[1:])
    # intra-tuple correlations
    cnt = 0
    for i in range(atts-1):
        for j in range(i+1, atts):
            write(fout, cols[i], cols[j], cnt)
            cnt = cnt + 1
    fout.write(MID)
    # inter-tuple correlations
    cnt = 0
    for i in range(atts):
        for j in range(atts, ncol):
            write(fout, cols[i], cols[j], cnt)
            cnt = cnt + 1
    fout.write(END)
    fout.close()


if __name__ == "__main__":
    main()
